#!/usr/bin/perl

use strict;


my $totalCpus = 0;
open(STATUS,"condor_status -long|") or die("Can't read the status. $?, $!\n");
while(<STATUS>) {
  if (/^Name = \"(.*)\"/) {
    my $slot = $1;
    open(SLOT,"condor_status -long $slot|") or die("Can't read the slot. $?, $!\n");
    while(<SLOT>) {
      if (/^Cpus = (\d+)/) {
        $totalCpus = $totalCpus + $1;
      }
    }
    close(SLOT);
  }
}
close(STATUS);

my $multiCoreTotal = 0;
my $singleCoreTotal = 0;
my $weirdCoreTotal = 0;
my $requestedCpus = 0;
open(Q,"condor_q|") or die("Can't read the queue. $?, $!\n");
while(<Q>) {
  if (/ R /) {
    my $job = $_;
    chomp($job);
    $job =~ s/\s+.*//;
    open(J,"condor_q -long $job|") or die("Could not read job attributes. $?, $!");
    while(<J>) {
      if (/^RequestCpus = (\d+)/) {
        my $cores = $1;
        $requestedCpus = $requestedCpus + $cores;
        if ($cores == 1) {
          $singleCoreTotal++;
        }
        elsif ($cores == 8) {
          $multiCoreTotal = $multiCoreTotal + 8;
        }
        else {
          $weirdCoreTotal++;
        }
      }
    }
    close(J);
  }
}
close(Q);

my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst)=localtime(time); 
my $timeStamp = sprintf ( "%04d%02d%02d %02d:%02d:%02d", $year+1900,$mon+1,$mday,$hour,$min,$sec);

print ("$timeStamp : Running report: ");
print ("TotalCpus = $totalCpus, ");
print ("RequestedCPUs = $requestedCpus, ");
print ("MultiCoreTotal = $multiCoreTotal, ");
print ("SingleCoreTotal = $singleCoreTotal");
print (", WeirdCoreTotal = $weirdCoreTotal") unless ($weirdCoreTotal == 0);
print("\n");

my $multiCoreTotal = 0;
my $singleCoreTotal = 0;
my $weirdCoreTotal = 0;
open(Q,"condor_q|") or die("Can't read the queue. $?, $!\n");
while(<Q>) {
  if (/ I /) {
    my $job = $_;
    chomp($job);
    $job =~ s/\s+.*//;
    open(J,"condor_q -long $job|") or die("Could not read job attributes. $?, $!");
    while(<J>) {
      if (/^RequestCpus = (\d+)/) {
        my $cores = $1;
        if ($cores == 1) {
          $singleCoreTotal++;
        }
        elsif ($cores == 8) {
          $multiCoreTotal = $multiCoreTotal + 8;
        }
        else {
          $weirdCoreTotal++;
        }
      }
    }
    close(J);
  }
}
close(Q);

my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst)=localtime(time); 
my $timeStamp = sprintf ( "%04d%02d%02d %02d:%02d:%02d", $year+1900,$mon+1,$mday,$hour,$min,$sec);

print ("$timeStamp : Queueing report : ");
print ("MultiCoreTotal = $multiCoreTotal, ");
print ("SingleCoreTotal = $singleCoreTotal");
print (", WeirdCoreTotal = $weirdCoreTotal") unless ($weirdCoreTotal == 0);
print("\n");

